"IlluminaMethylationManifest"## ConstructorIlluminaMethylationManifest(TypeI = new("DataFrame"),
TypeII = new("DataFrame"),
TypeControl = new("DataFrame"),
TypeSnpI = new("DataFrame"),
TypeSnpII = new("DataFrame"),
annotation = "")
## Data extraction
## S3 method for class 'IlluminaMethylationManifest':
getManifest(object)
## S3 method for class 'character':
getManifest(object)
getProbeInfo(object, type = c("I", "II", "Control",
"I-Green", "I-Red", "SnpI", "SnpII"))
getManifestInfo(object, type = c("nLoci", "locusNames"))
getControlAddress(object, controlType = c("NORM_A", "NORM_C",
"NORM_G", "NORM_T"),
asList = FALSE)
getControlTypes(object)
IlluminaMethylationManifest or class character for
getManifest. For getProbeInfo, getManifestInfo
and getControlAddress an object of either class
RGChannelSet, IlluminaMethylationManifest.DataFrame of type I probes.DataFrame of type II probes.DataFrame of control probes.DataFrame of SNP type I probes.DataFrame of SNP type II probes.character.getProbeInfo it represents the following
subtypes of probes on the array: Type I, Type II, Controls as well
as Type I (methylation measured in the Green channel) and Type II
(methylation measured in the Red channel). For
getManifestInfo it represents either the number of
methylation loci (approx. number of CpGs) on the array or the locus names.TRUE the return object is a list with one
component for each controlType.data slot contains the following objects: TypeI,
TypeII and TypeControl which are all of class
data.frame, describing the array design. Methylation loci of type I are measured using two different probes, in
either the red or the green channel. The columns AddressA,
AddresB describes the physical location of the two probes on
the array (with ProbeSeqA, ProbeSeqB giving the probe
sequences), and the column Color describes which color channel
is used.
Methylation loci of type II are measured using a single probe, but with two different color channels. The methylation signal is always measured in the green channel.
IlluminaMethylationAnnotation for annotation
information for the array (information depending on a specific genome
build).if(require(IlluminaHumanMethylation450kmanifest)) {
show(IlluminaHumanMethylation450kmanifest)
head(getProbeInfo(IlluminaHumanMethylation450kmanifest, type = "I"))
head(IlluminaHumanMethylation450kmanifest@data$TypeI)
head(IlluminaHumanMethylation450kmanifest@data$TypeII)
head(IlluminaHumanMethylation450kmanifest@data$TypeControl)
}Run the code above in your browser using DataLab